==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressInstanceFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StressInstanceFluentImpl<A extends StressInstanceFluent<A>> extends BaseFluent<A> implements StressInstanceFluent<A>{
  public StressInstanceFluentImpl() {
  }
  public StressInstanceFluentImpl(StressInstance instance) {
    this.withMemoryStartTime(instance.getMemoryStartTime()); 
    this.withMemoryUid(instance.getMemoryUid()); 
    this.withStartTime(instance.getStartTime()); 
    this.withUid(instance.getUid()); 
  }
  private String memoryStartTime;
  private String memoryUid;
  private String startTime;
  private String uid;
  public String getMemoryStartTime() {
    return this.memoryStartTime;
  }
  public A withMemoryStartTime(String memoryStartTime) {
    this.memoryStartTime=memoryStartTime; return (A) this;
  }
  public Boolean hasMemoryStartTime() {
    return this.memoryStartTime != null;
  }
  public String getMemoryUid() {
    return this.memoryUid;
  }
  public A withMemoryUid(String memoryUid) {
    this.memoryUid=memoryUid; return (A) this;
  }
  public Boolean hasMemoryUid() {
    return this.memoryUid != null;
  }
  public String getStartTime() {
    return this.startTime;
  }
  public A withStartTime(String startTime) {
    this.startTime=startTime; return (A) this;
  }
  public Boolean hasStartTime() {
    return this.startTime != null;
  }
  public String getUid() {
    return this.uid;
  }
  public A withUid(String uid) {
    this.uid=uid; return (A) this;
  }
  public Boolean hasUid() {
    return this.uid != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StressInstanceFluentImpl that = (StressInstanceFluentImpl) o;
    if (memoryStartTime != null ? !memoryStartTime.equals(that.memoryStartTime) :that.memoryStartTime != null) return false;
    if (memoryUid != null ? !memoryUid.equals(that.memoryUid) :that.memoryUid != null) return false;
    if (startTime != null ? !startTime.equals(that.startTime) :that.startTime != null) return false;
    if (uid != null ? !uid.equals(that.uid) :that.uid != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(memoryStartTime,  memoryUid,  startTime,  uid,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (memoryStartTime != null) { sb.append("memoryStartTime:"); sb.append(memoryStartTime + ","); }
    if (memoryUid != null) { sb.append("memoryUid:"); sb.append(memoryUid + ","); }
    if (startTime != null) { sb.append("startTime:"); sb.append(startTime + ","); }
    if (uid != null) { sb.append("uid:"); sb.append(uid); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressInstanceFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StressInstanceFluentImpl<A extends StressInstanceFluent<A>> extends BaseFluent<A> implements StressInstanceFluent<A>{
  public StressInstanceFluentImpl() {
  }
  public StressInstanceFluentImpl(StressInstance instance) {
    if (instance != null) {
      this.withMemoryStartTime(instance.getMemoryStartTime());
      this.withMemoryUid(instance.getMemoryUid());
      this.withStartTime(instance.getStartTime());
      this.withUid(instance.getUid());
    }
  }
  private String memoryStartTime;
  private String memoryUid;
  private String startTime;
  private String uid;
  public String getMemoryStartTime() {
    return this.memoryStartTime;
  }
  public A withMemoryStartTime(String memoryStartTime) {
    this.memoryStartTime=memoryStartTime; return (A) this;
  }
  public Boolean hasMemoryStartTime() {
    return this.memoryStartTime != null;
  }
  public String getMemoryUid() {
    return this.memoryUid;
  }
  public A withMemoryUid(String memoryUid) {
    this.memoryUid=memoryUid; return (A) this;
  }
  public Boolean hasMemoryUid() {
    return this.memoryUid != null;
  }
  public String getStartTime() {
    return this.startTime;
  }
  public A withStartTime(String startTime) {
    this.startTime=startTime; return (A) this;
  }
  public Boolean hasStartTime() {
    return this.startTime != null;
  }
  public String getUid() {
    return this.uid;
  }
  public A withUid(String uid) {
    this.uid=uid; return (A) this;
  }
  public Boolean hasUid() {
    return this.uid != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StressInstanceFluentImpl that = (StressInstanceFluentImpl) o;
    if (!java.util.Objects.equals(memoryStartTime, that.memoryStartTime)) return false;

    if (!java.util.Objects.equals(memoryUid, that.memoryUid)) return false;

    if (!java.util.Objects.equals(startTime, that.startTime)) return false;

    if (!java.util.Objects.equals(uid, that.uid)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(memoryStartTime,  memoryUid,  startTime,  uid,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (memoryStartTime != null) { sb.append("memoryStartTime:"); sb.append(memoryStartTime + ","); }
    if (memoryUid != null) { sb.append("memoryUid:"); sb.append(memoryUid + ","); }
    if (startTime != null) { sb.append("startTime:"); sb.append(startTime + ","); }
    if (uid != null) { sb.append("uid:"); sb.append(uid); }
    sb.append("}");
    return sb.toString();
  }
  
}
